@@ -2,7 +2,7 @@
  * Routines for AJP13 dissection
  * Copyright 2002, Christopher K. St. John <cks@distributopia.com>
  *
- * $Id: packet-ajp13.c 21253 2007-03-28 21:55:11Z sfisher $
+ * $Id: packet-ajp13.c 27866 2009-03-27 16:17:31Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -244,18 +244,18 @@ static guint16
 get_nstring(tvbuff_t *tvb, gint offset, guint8* cbuf, size_t cbuflen)
 {
   guint16 len;
-  guint16 copylen;
+  size_t copylen;
 
   len = tvb_get_ntohs(tvb, offset);
 
-  if (len == 0xffff) {
+  if (len == 0xffff || cbuflen < 1) {
     cbuf[0] = '\0';
     len = 0;
   } else {
     copylen = len;
     if (copylen > cbuflen - 1)
       copylen = cbuflen - 1;
-    tvb_memcpy(tvb, cbuf, offset+2, copylen);
+    tvb_memcpy(tvb, cbuf, offset+2, (gint) copylen);
     cbuf[copylen] = '\0';
     len++;
   }
@@ -345,7 +345,7 @@ display_rsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ajp13_tree)
 
       guint8 hcd;
       guint8 hid;
-      char hval[8192];
+      guint8 hval[8192];
       guint16 hval_len;
       int orig_pos = pos;
       const gchar* hname = NULL;
@@ -598,7 +598,7 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
     const gchar* hname = NULL;
     int dp = 0;
     int cl = 0;
-    char *hval;
+    guint8 *hval;
     guint16 hval_len;
 
     /* HEADER CODE/NAME
