@@ -3,7 +3,7 @@
  * Routines for FIP dissection - FCoE Initialization Protocol
  * Copyright (c) 2008 Cisco Systems, Inc. (jeykholt@cisco.com)
  *
- * $Id: packet-fip.c 26647 2008-10-31 15:11:57Z stig $
+ * $Id: packet-fip.c 30673 2009-10-23 16:27:44Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -526,20 +526,22 @@ proto_register_fip(void)
         { &hf_fip_desc_pri,
           {"Priority", "fip.pri", FT_UINT8, BASE_DEC, NULL, 0, "", HFILL}},
         { &hf_fip_desc_mac,
-          {"MAC Address", "fip.mac", FT_ETHER, 0, NULL, 0, "", HFILL}},
+          {"MAC Address", "fip.mac", FT_ETHER, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_map,
-          {"FC-MAP-OUI", "fip.map", FT_BYTES, BASE_HEX, NULL, 0, "", HFILL}},
+          {"FC-MAP-OUI", "fip.map", FT_STRING, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_name,
           {"Switch or Node Name", "fip.name", FT_STRING, BASE_HEX, NULL,
             0, "", HFILL}},
         { &hf_fip_desc_fab_vfid,
-          {"VFID Descriptor", "fip.fab.vfid", FT_STRING, BASE_DEC, NULL,
+          {"VFID", "fip.fab.vfid", FT_UINT16, BASE_DEC, NULL,
             0, "", HFILL}},
         { &hf_fip_desc_fab_map,
           {"FC-MAP", "fip.fab.map", FT_STRING, BASE_HEX, NULL,
             0, "", HFILL}},
         { &hf_fip_desc_fab_name,
-          {"Fabric Descriptor", "fip.fab.name", FT_STRING, BASE_HEX, NULL,
+          {"Fabric Name", "fip.fab.name", FT_STRING, BASE_NONE, NULL,
             0, "", HFILL}},
         { &hf_fip_desc_fcoe_size,
           {"Max FCoE frame size", "fip.fcoe_size", FT_UINT16, BASE_DEC, NULL,
@@ -557,7 +559,8 @@ proto_register_fip(void)
           {"FKA_ADV_Period", "fip.fka", FT_UINT32, BASE_DEC, NULL,
             0, "", HFILL}},
         { &hf_fip_desc_vend,
-          {"Vendor-ID", "fip.vendor", FT_BYTES, BASE_HEX, NULL, 0, "", HFILL}},
+          {"Vendor-ID", "fip.vendor", FT_BYTES, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_vend_data,
           {"Vendor-specific data", "fip.vendor.data", FT_BYTES, BASE_HEX, NULL,
             0, "", HFILL}},
