@@ -12,7 +12,7 @@
  *
  * for the current Internet-Draft for IAX2.
  *
- * $Id: packet-iax2.c 27050 2008-12-18 19:08:49Z wmeier $
+ * $Id: packet-iax2.c 30927 2009-11-10 22:09:20Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -47,6 +47,8 @@
 #include <epan/emem.h>
 #include <epan/reassemble.h>
 #include <epan/aftypes.h>
+#include <epan/tap.h>
+#include <epan/tap-voip.h>
 
 #include "packet-iax2.h"
 #include <epan/iax2_codec_type.h>
@@ -67,6 +69,13 @@
 /* Wireshark ID of the IAX2 protocol */
 static int proto_iax2 = -1;
 
+/* tap register id */
+static int iax2_tap = -1;
+
+/* protocol tap info */
+static iax2_info_t ii_arr[1];
+static iax2_info_t *iax2_info = ii_arr;
+
 /* The following hf_* variables are used to hold the wireshark IDs of
  * our header fields; they are filled out when we call
  * proto_register_field_array() in proto_register_iax2()
@@ -247,6 +256,19 @@ static const value_string iax_cmd_subclasses[] = {
   {0,NULL}
 };
 
+/* IAX2 to tap-voip call state mapping */
+static const voip_call_state tap_cmd_voip_state[] = {
+	VOIP_NO_STATE,
+        VOIP_COMPLETED, /*HANGUP*/
+        VOIP_RINGING, /*RING*/
+        VOIP_RINGING, /*RINGING*/
+        VOIP_IN_CALL, /*ANSWER*/
+        VOIP_REJECTED, /*BUSY*/
+        VOIP_UNKNOWN, /*TKOFFHK*/
+        VOIP_UNKNOWN /*OFFHOOK*/
+};
+	
+
 /* Subclassess for Modem packets */
 static const value_string iax_modem_subclasses[] = {
   {0, "(0?)"},
@@ -338,12 +360,6 @@ static const value_string iax_dataformats[] = {
   {0,NULL}
 };
 
-typedef enum {
-  IAX2_MINI_VOICE_PACKET,
-  IAX2_FULL_PACKET,
-  IAX2_MINI_VIDEO_PACKET,
-  IAX2_META_PACKET
-} packet_type;
 
 static const value_string iax_packet_types[] = {
   {IAX2_FULL_PACKET, "Full packet"},
@@ -1046,18 +1062,34 @@ dissect_iax2 (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       proto_tree_add_item (full_mini_subtree, hf_iax2_scallno, tvb, offset-2, 2, FALSE);
   }
 
+  iax2_info->ptype = type;
+  iax2_info->scallno = 0;
+  iax2_info->dcallno = 0;
+  iax2_info->ftype = 0;
+  iax2_info->csub = 0;
+  iax2_info->payload_len = 0;
+  iax2_info->timestamp = 0;
+  iax2_info->callState = VOIP_NO_STATE;
+  iax2_info->messageName = NULL;
+  iax2_info->callingParty = NULL;
+  iax2_info->calledParty = NULL;
+  iax2_info->payload_data = NULL;
+  
   switch( type ) {
     case IAX2_FULL_PACKET:
       len = dissect_fullpacket( tvb, offset, scallno, pinfo, full_mini_subtree, tree );
       break;
     case IAX2_MINI_VOICE_PACKET:
+      iax2_info->messageName = "MINI_VOICE_PACKET";
       len = dissect_minipacket( tvb, offset, scallno, pinfo, full_mini_subtree, tree );
       break;
     case IAX2_MINI_VIDEO_PACKET:
+      iax2_info->messageName = "MINI_VIDEO_PACKET";
       len = dissect_minivideopacket( tvb, offset, scallno, pinfo, full_mini_subtree, tree );
       break;
     case IAX2_META_PACKET:
       /* not implemented yet */
+      iax2_info->messageName = "META_PACKET";
       len = 0;
       break;
     default:
@@ -1067,6 +1099,7 @@ dissect_iax2 (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
   /* update the 'length' of the main IAX2 header field so that it covers just the headers,
      not the audio data. */
   proto_item_set_len(iax2_item, len);
+  tap_queue_packet(iax2_tap, pinfo, iax2_info);
 }
 
 static proto_item *dissect_datetime_ie(tvbuff_t *tvb, guint32 offset, proto_tree *ies_tree)
@@ -1113,6 +1146,13 @@ static guint32 dissect_ies (tvbuff_t * tvb, guint32 offset,
         if (ies_len != 4) THROW(ReportedBoundsError);
         ie_data -> dataformat = tvb_get_ntohl(tvb, offset+2);
         break;
+      
+      case IAX_IE_CALLED_NUMBER:
+        iax2_info->calledParty = g_strdup(tvb_format_text(tvb, offset+2, ies_len));
+        break;
+      case IAX_IE_CALLING_NUMBER:
+        iax2_info->callingParty = g_strdup(tvb_format_text(tvb, offset+2, ies_len));
+        break;
 
       case IAX_IE_APPARENT_ADDR:
         /* The IAX2 I-D says that the "apparent address" structure
@@ -1417,15 +1457,18 @@ static void iax2_add_ts_fields(packet_info * pinfo, proto_tree * iax2_tree, iax_
       iax_packet->abstime.secs ++;
     }
   }
+  iax2_info->timestamp = longts;
   
-  item = proto_tree_add_time(iax2_tree, hf_iax2_absts, NULL, 0, 0, &iax_packet->abstime);
-  PROTO_ITEM_SET_GENERATED(item);
+  if (iax2_tree) {
+    item = proto_tree_add_time(iax2_tree, hf_iax2_absts, NULL, 0, 0, &iax_packet->abstime);
+    PROTO_ITEM_SET_GENERATED(item);
 
-  ts  = pinfo->fd->abs_ts;
-  nstime_delta(&ts, &ts, &iax_packet->abstime);
+    ts  = pinfo->fd->abs_ts;
+    nstime_delta(&ts, &ts, &iax_packet->abstime);
   
-  item = proto_tree_add_time(iax2_tree, hf_iax2_lateness, NULL, 0, 0, &ts);
-  PROTO_ITEM_SET_GENERATED(item);
+    item = proto_tree_add_time(iax2_tree, hf_iax2_lateness, NULL, 0, 0, &ts);
+    PROTO_ITEM_SET_GENERATED(item);
+  }
 }
 
 /* returns the new offset */
@@ -1457,6 +1500,10 @@ dissect_fullpacket (tvbuff_t * tvb, guint32 offset,
   ts = tvb_get_ntohl(tvb, offset+2);
   type = tvb_get_guint8(tvb, offset + 8);
   csub = tvb_get_guint8(tvb, offset + 9);
+  iax2_info->ftype = type;
+  iax2_info->csub = csub;
+  iax2_info->scallno = scallno;
+  iax2_info->dcallno = dcallno;
 
   /* see if we've seen this packet before */
   iax_packet = (iax_packet_data *)p_get_proto_data(pinfo->fd,proto_iax2);
@@ -1508,18 +1555,24 @@ dissect_fullpacket (tvbuff_t * tvb, guint32 offset,
 
       /* add the type-specific subtree */
       packet_type_tree = proto_item_add_subtree (packet_type_base, ett_iax2_type);
+  } else {
+    iax2_add_ts_fields(pinfo, iax2_tree, iax_packet, (guint16)ts);
   }
 
+
   /* add frame type to info line */
   if (check_col (pinfo->cinfo, COL_INFO)) {
     col_add_fstr (pinfo->cinfo, COL_INFO, "%s, source call# %d, timestamp %ums",
 		  val_to_str (type, iax_frame_types, "Unknown (0x%02x)"),
 		  scallno, ts);
   }
+  iax2_info->messageName = val_to_str (type, iax_frame_types, "Unknown (0x%02x)");
 
   switch( type ) {
   case AST_FRAME_IAX:
     offset=dissect_iax2_command(tvb,offset+9,pinfo,packet_type_tree,iax_packet);
+    iax2_info->messageName = val_to_str (csub, iax_iax_subclasses, "unknown (0x%02x)");
+    iax2_info->callState = csub;
     break;
     
   case AST_FRAME_DTMF_BEGIN:
@@ -1540,6 +1593,8 @@ dissect_fullpacket (tvbuff_t * tvb, guint32 offset,
     if (check_col (pinfo->cinfo, COL_INFO))
       col_append_fstr (pinfo->cinfo, COL_INFO, " %s",
 		    val_to_str (csub, iax_cmd_subclasses, "unknown (0x%02x)"));
+    iax2_info->messageName = val_to_str (csub, iax_cmd_subclasses, "unknown (0x%02x)");
+    if (csub <= 8) iax2_info->callState = tap_cmd_voip_state[csub];
     break;
 
   case AST_FRAME_VOICE:
@@ -1683,6 +1738,8 @@ static guint32 dissect_minivideopacket (tvbuff_t * tvb, guint32 offset,
     proto_tree_add_item (iax2_tree, hf_iax2_minividts, tvb, offset, 2, FALSE);
     iax2_add_ts_fields(pinfo, iax2_tree, iax_packet, (guint16)ts);
     proto_tree_add_item (iax2_tree, hf_iax2_minividmarker, tvb, offset, 2, FALSE);
+  } else {
+    iax2_add_ts_fields(pinfo, iax2_tree, iax_packet, (guint16)ts);
   }
 
   offset += 2;
@@ -1723,7 +1780,10 @@ dissect_minipacket (tvbuff_t * tvb, guint32 offset, guint16 scallno, packet_info
 
     proto_tree_add_uint (iax2_tree, hf_iax2_minits, tvb, offset, 2, ts);
     iax2_add_ts_fields(pinfo, iax2_tree, iax_packet,(guint16)ts);
+  } else {
+    iax2_add_ts_fields(pinfo, iax2_tree, iax_packet, (guint16)ts);
   }
+
   
   offset += 2;
   
@@ -1832,8 +1892,7 @@ static void desegment_iax(tvbuff_t *tvb, packet_info *pinfo, proto_tree *iax2_tr
     
     if(fd_head && (pinfo->fd->num == fd_head->reassembled_in)) {
       gint32 old_len;
-      tvbuff_t *next_tvb = tvb_new_real_data(fd_head->data, fd_head->datalen, fd_head->datalen);
-      tvb_set_child_real_data_tvbuff(tvb, next_tvb); 
+      tvbuff_t *next_tvb = tvb_new_child_real_data(tvb, fd_head->data, fd_head->datalen, fd_head->datalen);
       add_new_data_source(pinfo, next_tvb, "Reassembled IAX2");
 
       process_iax_pdu(next_tvb,pinfo,tree,video,iax_packet);
@@ -2000,6 +2059,9 @@ static void dissect_payload(tvbuff_t *tvb, guint32 offset,
   proto_tree_add_text( iax2_tree, sub_tvb, 0, -1,
       "IAX2 payload (%u byte%s)", nbytes,
       plurality( nbytes, "", "s" ));
+      
+  iax2_info->payload_len = nbytes;      
+  iax2_info->payload_data = tvb_get_ptr(sub_tvb, 0, -1);
 
   /* pass the rest of the block to a subdissector */
   if(iax_packet->call_data)
@@ -2027,12 +2089,6 @@ iax_init_protocol(void)
 void
 proto_register_iax2 (void)
 {
-  /* we use this for displaying which codecs are supported */
-  static const true_false_string supported_strings = {
-    "Supported",
-    "Not supported"
-  };
-
   /* A header field is something you can search/filter on.
    * 
    * We create a structure to register our fields. It consists of an
@@ -2089,7 +2145,7 @@ proto_register_iax2 (void)
 
     {&hf_iax2_absts,
      {"Absolute Time", "iax2.abstime", FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-      "The absolute time of this packet (calculated by adding the IAX timestamp to "
+      "The absoulte time of this packet (calculated by adding the IAX timestamp to "
       " the start time of this call)",
       HFILL}},
 
@@ -2414,77 +2470,77 @@ proto_register_iax2 (void)
     /* capablilites */
     {&hf_iax2_cap_g723_1,
      {"G.723.1 compression", "iax2.cap.g723_1", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_G723_1,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_G723_1,
       "G.723.1 compression", HFILL }},
 
     {&hf_iax2_cap_gsm,
      {"GSM compression", "iax2.cap.gsm", FT_BOOLEAN, 32,
-       TFS(&supported_strings), AST_FORMAT_GSM, 
+       TFS(&tfs_supported_not_supported), AST_FORMAT_GSM, 
       "GSM compression", HFILL }},
 
     {&hf_iax2_cap_ulaw,
      {"Raw mu-law data (G.711)", "iax2.cap.ulaw",FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_ULAW,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_ULAW,
       "Raw mu-law data (G.711)", HFILL }},
 
      {&hf_iax2_cap_alaw,
       {"Raw A-law data (G.711)", "iax2.cap.alaw",FT_BOOLEAN, 32,
-       TFS(&supported_strings), AST_FORMAT_ALAW,
+       TFS(&tfs_supported_not_supported), AST_FORMAT_ALAW,
        "Raw A-law data (G.711)", HFILL }},
 
     {&hf_iax2_cap_g726,
      {"G.726 compression", "iax2.cap.g726",FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_G726,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_G726,
       "G.726 compression", HFILL }},
 
     {&hf_iax2_cap_adpcm,
      {"ADPCM", "iax2.cap.adpcm", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_ADPCM,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_ADPCM,
       "ADPCM", HFILL }},
     
     {&hf_iax2_cap_slinear,
      {"Raw 16-bit Signed Linear (8000 Hz) PCM", "iax2.cap.slinear", 
-      FT_BOOLEAN, 32, TFS(&supported_strings), AST_FORMAT_SLINEAR, 
+      FT_BOOLEAN, 32, TFS(&tfs_supported_not_supported), AST_FORMAT_SLINEAR, 
       "Raw 16-bit Signed Linear (8000 Hz) PCM", HFILL }},
 
     {&hf_iax2_cap_lpc10,
      {"LPC10, 180 samples/frame", "iax2.cap.lpc10", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_LPC10,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_LPC10,
       "LPC10, 180 samples/frame", HFILL }},
 
     {&hf_iax2_cap_g729a,
      {"G.729a Audio", "iax2.cap.g729a", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_G729A,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_G729A,
       "G.729a Audio", HFILL }},
 
     {&hf_iax2_cap_speex,
      {"SPEEX Audio", "iax2.cap.speex", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_SPEEX,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_SPEEX,
       "SPEEX Audio", HFILL }},
 
     {&hf_iax2_cap_ilbc,
      {"iLBC Free compressed Audio", "iax2.cap.ilbc", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_ILBC,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_ILBC,
       "iLBC Free compressed Audio", HFILL }},
 
     {&hf_iax2_cap_jpeg,
      {"JPEG images", "iax2.cap.jpeg", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_JPEG,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_JPEG,
       "JPEG images", HFILL }},
 
     {&hf_iax2_cap_png,
      {"PNG images", "iax2.cap.png", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_PNG,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_PNG,
       "PNG images", HFILL }},
 
     {&hf_iax2_cap_h261,
      {"H.261 video", "iax2.cap.h261", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_H261,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_H261,
       "H.261 video", HFILL }},
 
     {&hf_iax2_cap_h263,
      {"H.263 video", "iax2.cap.h263", FT_BOOLEAN, 32,
-      TFS(&supported_strings), AST_FORMAT_H263,
+      TFS(&tfs_supported_not_supported), AST_FORMAT_H263,
       "H.263 video", HFILL }},
 
     /* reassembly stuff */
@@ -2555,13 +2611,18 @@ proto_register_iax2 (void)
   /* register our init routine to be called at the start of a capture,
      to clear out our hash tables etc */
   register_init_routine(&iax_init_protocol);
+  iax2_tap = register_tap("IAX2");
 }
 
 void
 proto_reg_handoff_iax2 (void)
 {
+  dissector_handle_t v110_handle = NULL;
+  
   dissector_add("udp.port", IAX2_PORT, find_dissector("iax2"));
-  dissector_add("iax2.dataformat", AST_DATAFORMAT_V110, find_dissector("v110"));
+  v110_handle =  find_dissector("v110");
+  if(v110_handle)
+	  dissector_add("iax2.dataformat", AST_DATAFORMAT_V110, v110_handle);
   data_handle = find_dissector("data");
 }
 
