@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-sdp.c 26938 2008-12-08 21:31:37Z etxrab $
+ * $Id: packet-sdp.c 31012 2009-11-19 04:53:43Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,7 +52,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
 #include <epan/strutil.h>
 #include <epan/emem.h>
 #include <epan/base64.h>
@@ -167,6 +166,7 @@ static int hf_media_sample_rate = -1;
 static int hf_media_format_specific_parameter = -1;
 static int hf_sdp_fmtp_mpeg4_profile_level_id = -1;
 static int hf_sdp_fmtp_h263_profile = -1;
+static int hf_sdp_fmtp_h263_level = -1;
 static int hf_sdp_h264_packetization_mode = -1;
 static int hf_sdp_h264_sprop_parameter_sets = -1;
 static int hf_SDPh223LogicalChannelParameters = -1;
@@ -194,7 +194,7 @@ static int ett_sdp_key_mgmt = -1;
 
 #define SDP_MAX_RTP_CHANNELS 4
 #define SDP_MAX_RTP_PAYLOAD_TYPES 20
-
+#define SDP_NO_OF_PT 128
 typedef struct {
   gint32 pt[SDP_MAX_RTP_PAYLOAD_TYPES];
   gint8 pt_count;
@@ -204,7 +204,8 @@ typedef struct {
 typedef struct {
   char *connection_address;
   char *connection_type;
-  char *encoding_name;
+  char *media_type;
+  char *encoding_name[SDP_NO_OF_PT]; 
   char *media_port[SDP_MAX_RTP_CHANNELS];
   char *media_proto[SDP_MAX_RTP_CHANNELS];
   transport_media_pt_t media[SDP_MAX_RTP_CHANNELS];
@@ -276,9 +277,11 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   gboolean    set_rtp=FALSE;
   gboolean    is_ipv4_addr=FALSE;
   gboolean    is_ipv6_addr=FALSE;
+  gboolean    is_video=FALSE;
   guint32     ipaddr[4];
   gint        n,i;
   sdp_packet_info *sdp_pi;
+  gchar       *unknown_encoding = ep_strdup("Unknown");
 
   /* Initialise packet info for passing to tap */
   sdp_pi = ep_alloc(sizeof(sdp_packet_info));
@@ -287,7 +290,10 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   /* Initialise RTP channel info */
   transport_info.connection_address=NULL;
   transport_info.connection_type=NULL;
-  transport_info.encoding_name=NULL;
+  transport_info.media_type=NULL;
+  for (n=0; n < SDP_NO_OF_PT; n++){
+	  transport_info.encoding_name[n]=unknown_encoding;
+  }
   for (n=0; n < SDP_MAX_RTP_CHANNELS; n++)
   {
     transport_info.media_port[n]=NULL;
@@ -481,6 +487,9 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         }
       }
     }
+	if (strcmp(transport_info.media_type,"video")==0){
+		is_video = TRUE;
+	}
     set_rtp = FALSE;
     /* Add (s)rtp and (s)rtcp conversation, if available (overrides t38 if conversation already set) */
     if((!pinfo->fd->flags.visited) && port!=0 && (is_rtp||is_srtp) && (is_ipv4_addr || is_ipv6_addr)){
@@ -488,10 +497,10 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       if(rtp_handle){
         if (is_srtp) {
           struct srtp_info *dummy_srtp_info = se_alloc0(sizeof(struct srtp_info));
-          srtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num,
+          srtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num, is_video,
                            transport_info.media[n].rtp_dyn_payload, dummy_srtp_info);
         } else {
-          rtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num,
+          rtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num, is_video,
                           transport_info.media[n].rtp_dyn_payload);
         }
         set_rtp = TRUE;
@@ -930,8 +939,7 @@ static void dissect_key_mgmt(tvbuff_t *tvb, packet_info * pinfo, proto_item * ti
     return;
 
   data = tvb_get_ephemeral_string(tvb, offset, len);
-  keymgmt_tvb = base64_to_tvb(data);
-  tvb_set_child_real_data_tvbuff(tvb, keymgmt_tvb);
+  keymgmt_tvb = base64_to_tvb(tvb, data);
   add_new_data_source(pinfo, keymgmt_tvb, "Key Management Data");
 
   if ( prtcl_id != NULL && key_mgmt_dissector_table != NULL ) {
@@ -1020,6 +1028,7 @@ static void dissect_sdp_session_attribute(tvbuff_t *tvb, packet_info * pinfo, pr
   }
 }
 
+
 /* Dissect media description */
 static void
 dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
@@ -1049,6 +1058,8 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
   proto_tree_add_item(sdp_media_tree, hf_media_media, tvb, offset, tokenlen,
                       FALSE);
 
+  transport_info->media_type = (char*)tvb_get_ephemeral_string(tvb, offset, tokenlen);
+
   offset = next_offset + 1;
 
   next_offset = tvb_find_guint8(tvb,offset, -1, ' ');
@@ -1142,7 +1153,8 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
 
 }
 
-tvbuff_t *ascii_bytes_to_tvb(tvbuff_t *tvb, packet_info *pinfo, gint len, gchar *msg)
+static tvbuff_t *
+ascii_bytes_to_tvb(tvbuff_t *tvb, packet_info *pinfo, gint len, gchar *msg)
 {
 	guint8 *buf = ep_alloc(10240);
 
@@ -1208,8 +1220,7 @@ tvbuff_t *ascii_bytes_to_tvb(tvbuff_t *tvb, packet_info *pinfo, gint len, gchar
 		if(i==0){
 			return NULL;
 		}
-		bytes_tvb = tvb_new_real_data(buf,i,i);
-		tvb_set_child_real_data_tvbuff(tvb,bytes_tvb);
+		bytes_tvb = tvb_new_child_real_data(tvb, buf,i,i);
 		add_new_data_source(pinfo, bytes_tvb, "ASCII bytes to tvb");
 		return bytes_tvb;
 	}
@@ -1231,6 +1242,22 @@ static const value_string h263_profile_vals[] =
   { 0, NULL },
 };
 
+
+/* RFC 4629 The level are described in table X.2 of H.263 annex X */
+static const value_string h263_level_vals[] =
+{
+  { 10,    "QCIF (176 x 144), 1 x 64Kb/s" },
+  { 20,    "CIF (352 x 288), 2 x 64Kb/s" },
+  { 30,    "CIF (352 x 288), 6 x 64Kb/s" },
+  { 40,    "CIF (352 x 288), 32 x 64Kb/s" },
+  { 45,    "QCIF (176 x144) support of CPFMT, 2 x 64Kb/s" },
+  { 50,    "CIF (352 x 288) support of CPFMT, 64 x 64Kb/s" },
+  { 60,    "CPFMT: 720 x 288 support of CPFMT, 128 x 64Kb/s" },
+  { 70,    "CPFMT: 720 x 576 support of CPFMT, 256 x 64Kb/s" },
+  { 0, NULL },
+};
+
+
 static const value_string h264_packetization_mode_vals[] =
 {
   { 0,    "Single NAL mode" },
@@ -1243,7 +1270,7 @@ static const value_string h264_packetization_mode_vals[] =
  * TODO: Make this a more generic routine to dissect fmtp parameters depending on media types
  */
 static void
-decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset, gint tokenlen, guint8 *mime_type){
+decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset, gint tokenlen, char *mime_type){
   gint next_offset;
   gint end_offset;
   guint8 *field_name;
@@ -1275,7 +1302,7 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset
   offset = next_offset;
 
   /* Dissect the MPEG4 profile-level-id parameter if present */
-  if (mime_type != NULL && g_ascii_strcasecmp((char*)mime_type, "MP4V-ES") == 0) {
+  if (mime_type != NULL && g_ascii_strcasecmp(mime_type, "MP4V-ES") == 0) {
     if (strcmp((char*)field_name, "profile-level-id") == 0) {
       offset++;
       tokenlen = end_offset - offset;
@@ -1296,7 +1323,7 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset
   }
 
   /* Dissect the H263-2000 profile parameter if present */
-  if (mime_type != NULL && g_ascii_strcasecmp((char*)mime_type, "H263-2000") == 0) {
+  if ((mime_type != NULL && g_ascii_strcasecmp(mime_type, "H263-2000") == 0)||(mime_type != NULL && g_ascii_strcasecmp(mime_type, "H263-1998") == 0)) {
     if (strcmp((char*)field_name, "profile") == 0) {
       offset++;
       tokenlen = end_offset - offset;
@@ -1304,6 +1331,13 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset
       item = proto_tree_add_uint(tree, hf_sdp_fmtp_h263_profile, tvb, offset, tokenlen,
                                  atol((char*)format_specific_parameter));
       PROTO_ITEM_SET_GENERATED(item);
+	}else if(strcmp((char*)field_name, "level") == 0) {
+      offset++;
+      tokenlen = end_offset - offset;
+      format_specific_parameter = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+      item = proto_tree_add_uint(tree, hf_sdp_fmtp_h263_level, tvb, offset, tokenlen,
+                                 atol((char*)format_specific_parameter));
+      PROTO_ITEM_SET_GENERATED(item);
     }
   }
 
@@ -1343,6 +1377,7 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset
       format_specific_parameter = tvb_get_ephemeral_string(tvb, offset, tokenlen);
       item = proto_tree_add_uint(tree, hf_sdp_h264_packetization_mode, tvb, offset, tokenlen,
                                  atol((char*)format_specific_parameter));
+	  PROTO_ITEM_SET_GENERATED(item);
 
 	}else if (strcmp(field_name, "sprop-parameter-sets") == 0) {
 		/* The value of the parameter is the
@@ -1371,8 +1406,7 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset
 	    proto_tree_add_text(tree, tvb, offset, tokenlen, "NAL unit 1 string: %s", data);
 
 		/* proto_tree_add_text(tree, tvb, offset, tokenlen, "String %s",data); */
-		data_tvb = base64_to_tvb(data);
-		tvb_set_child_real_data_tvbuff(tvb, data_tvb);
+		data_tvb = base64_to_tvb(tvb, data);
 		add_new_data_source(pinfo, data_tvb, "h264 prop-parameter-sets");
 
 		if(h264_handle && data_tvb){
@@ -1383,8 +1417,7 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset
 				tokenlen = end_offset - offset;
 				data = tvb_get_ephemeral_string(tvb, offset, tokenlen);
 				proto_tree_add_text(tree, tvb, offset, tokenlen, "NAL unit 2 string: %s", data);
-				data_tvb = base64_to_tvb(data);
-				tvb_set_child_real_data_tvbuff(tvb, data_tvb);
+				data_tvb = base64_to_tvb(tvb, data);
 				add_new_data_source(pinfo, data_tvb, "h264 prop-parameter-sets 2");
 				dissect_h264_nal_unit(data_tvb, pinfo, tree);
 			}
@@ -1433,6 +1466,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
   guint8 *payload_type;
   guint8 *attribute_value;
   gint   *key;
+  guint8 pt;
   gint	sdp_media_attrbute_code;
   const char *msrp_res = "msrp://";
   const char *h324ext_h223lcparm = "h324ext/h223lcparm";
@@ -1500,11 +1534,15 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 
 	  proto_tree_add_item(sdp_media_attribute_tree, hf_media_encoding_name, tvb,
                         offset, tokenlen, FALSE);
-	  /* get_string is needed here as the string is "saved" in a hashtable */
-	  transport_info->encoding_name = (char*)tvb_get_ephemeral_string(tvb, offset, tokenlen);
-	
+
 	  key=g_malloc( sizeof(gint) );
 	  *key=atol((char*)payload_type);
+	  pt = atoi((char*)payload_type);
+          if (pt >= SDP_NO_OF_PT) {
+              return;   /* Invalid */ 
+          }
+	  transport_info->encoding_name[pt] = (char*)tvb_get_ephemeral_string(tvb, offset, tokenlen);
+	
 
 	  offset = next_offset + 1;
 	  tvb_find_line_end_unquoted(tvb, offset, -1, &next_offset);
@@ -1533,13 +1571,13 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 		  for (n=0; n < SDP_MAX_RTP_CHANNELS; n++) {
 			  if (n==0)
 				  g_hash_table_insert(transport_info->media[n].rtp_dyn_payload,
-                                    key, g_strdup(transport_info->encoding_name));
+                                    key, g_strdup(transport_info->encoding_name[pt]));
 			  else {    /* we create a new key and encoding_name to assign to the other hash tables */
 				  gint *key2;
 				  key2=g_malloc( sizeof(gint) );
 				  *key2=atol((char*)payload_type);
 				  g_hash_table_insert(transport_info->media[n].rtp_dyn_payload,
-					  key2, g_strdup(transport_info->encoding_name));
+					  key2, g_strdup(transport_info->encoding_name[pt]));
 			  }
 		  }
 		  return;
@@ -1548,13 +1586,14 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 		  /* in case there is an overflow in SDP_MAX_RTP_CHANNELS, we keep always the last "m=" */
 		  if (transport_info->media_count == SDP_MAX_RTP_CHANNELS-1)
 			  g_hash_table_insert(transport_info->media[ transport_info->media_count ].rtp_dyn_payload,
-					key, g_strdup(transport_info->encoding_name));
+					key, g_strdup(transport_info->encoding_name[pt]));
 		  else
 			  g_hash_table_insert(transport_info->media[ transport_info->media_count-1 ].rtp_dyn_payload,
-					key, g_strdup(transport_info->encoding_name));
+					key, g_strdup(transport_info->encoding_name[pt]));
 	  break;
   case SDP_FMTP:
 	  if(sdp_media_attribute_tree){
+		  guint8 media_format;
 		  /* Reading the Format parameter(fmtp) */
 		  /* Skip leading space, if any */
 		  offset = tvb_skip_wsp(tvb,offset,tvb_length_remaining(tvb,offset));
@@ -1570,10 +1609,14 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 		  media_format_item = proto_tree_add_item(sdp_media_attribute_tree,
                                             hf_media_format, tvb, offset,
                                             tokenlen, FALSE);
+		  media_format = atoi((char*)tvb_get_ephemeral_string(tvb, offset, tokenlen));
+		  if (media_format >= SDP_NO_OF_PT) {
+			  return;   /* Invalid */ 
+                  }
+
 		  /* Append encoding name to format if known */
-		  if (transport_info->encoding_name)
-			  proto_item_append_text(media_format_item, " [%s]",
-                             transport_info->encoding_name);
+		  proto_item_append_text(media_format_item, " [%s]",
+                             transport_info->encoding_name[media_format]);
 
 		  payload_type = tvb_get_ephemeral_string(tvb, offset, tokenlen);
 		  /* Move offset past the payload type */
@@ -1599,7 +1642,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 			  fmtp_tree = proto_item_add_subtree(fmtp_item, ett_sdp_fmtp);
 
 			  decode_sdp_fmtp(fmtp_tree, tvb, pinfo, offset, tokenlen,
-                      (guint8 *)transport_info->encoding_name);
+                      transport_info->encoding_name[media_format]);
 
 			  /* Move offset past "; " and onto firts char */	
 			  offset = next_offset + 1;
@@ -1612,7 +1655,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 		  int address_offset, port_offset, port_end_offset;
 
 		  /* Address starts here */
-		  address_offset = offset + strlen(msrp_res);
+		  address_offset = offset + (int)strlen(msrp_res);
 
 		  /* Port is after next ':' */
 		  port_offset = tvb_find_guint8(tvb, address_offset, -1, ':');
@@ -1641,7 +1684,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 		  gint len;
 		  asn1_ctx_t actx;
 
-		  len = strlen(attribute_value);
+		  len = (gint)strlen(attribute_value);
 		  h245_tvb = ascii_bytes_to_tvb(tvb, pinfo, len, attribute_value);
 		  /* arbitrary maximum length */
 		  /* should go through a handle, however,  the two h245 entry
@@ -1668,23 +1711,23 @@ proto_register_sdp(void)
     { &hf_protocol_version,
       { "Session Description Protocol Version (v)",
         "sdp.version", FT_STRING, BASE_NONE,NULL,0x0,
-        "Session Description Protocol Version", HFILL }},
+        NULL, HFILL }},
     { &hf_owner,
       { "Owner/Creator, Session Id (o)",
         "sdp.owner", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Owner/Creator, Session Id", HFILL}},
+        NULL, HFILL}},
     { &hf_session_name,
       { "Session Name (s)",
         "sdp.session_name", FT_STRING, BASE_NONE,NULL, 0x0,
-        "Session Name", HFILL }},
+        NULL, HFILL }},
     { &hf_session_info,
       { "Session Information (i)",
         "sdp.session_info", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session Information", HFILL }},
+        NULL, HFILL }},
     { &hf_uri,
       { "URI of Description (u)",
         "sdp.uri", FT_STRING, BASE_NONE,NULL, 0x0,
-        "URI of Description", HFILL }},
+        NULL, HFILL }},
     { &hf_email,
       { "E-mail Address (e)",
         "sdp.email", FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1692,43 +1735,43 @@ proto_register_sdp(void)
     { &hf_phone,
       { "Phone Number (p)",
         "sdp.phone", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Phone Number", HFILL }},
+        NULL, HFILL }},
     { &hf_connection_info,
       { "Connection Information (c)",
         "sdp.connection_info", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Connection Information", HFILL }},
+        NULL, HFILL }},
     { &hf_bandwidth,
       { "Bandwidth Information (b)",
         "sdp.bandwidth", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Bandwidth Information", HFILL }},
+        NULL, HFILL }},
     { &hf_timezone,
       { "Time Zone Adjustments (z)",
         "sdp.timezone", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Time Zone Adjustments", HFILL }},
+        NULL, HFILL }},
     { &hf_encryption_key,
       { "Encryption Key (k)",
         "sdp.encryption_key", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Encryption Key", HFILL }},
+        NULL, HFILL }},
     { &hf_session_attribute,
       { "Session Attribute (a)",
         "sdp.session_attr", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session Attribute", HFILL }},
+        NULL, HFILL }},
     { &hf_media_attribute,
       { "Media Attribute (a)",
         "sdp.media_attr", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Attribute", HFILL }},
+        NULL, HFILL }},
     { &hf_time,
       { "Time Description, active time (t)",
         "sdp.time", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Time Description, active time", HFILL }},
+        NULL, HFILL }},
     { &hf_repeat_time,
       { "Repeat Time (r)",
         "sdp.repeat_time", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Repeat Time", HFILL }},
+        NULL, HFILL }},
     { &hf_media,
       { "Media Description, name and address (m)",
         "sdp.media", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Description, name and address", HFILL }},
+        NULL, HFILL }},
     { &hf_media_title,
       { "Media Title (i)",
         "sdp.media_title",FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1736,27 +1779,27 @@ proto_register_sdp(void)
     { &hf_unknown,
       { "Unknown",
         "sdp.unknown",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Unknown", HFILL }},
+        NULL, HFILL }},
     { &hf_invalid,
       { "Invalid line",
         "sdp.invalid",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Invalid line", HFILL }},
+        NULL, HFILL }},
     { &hf_owner_username,
       { "Owner Username",
         "sdp.owner.username",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Owner Username", HFILL }},
+        NULL, HFILL }},
     { &hf_owner_sessionid,
       { "Session ID",
         "sdp.owner.sessionid",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session ID", HFILL }},
+        NULL, HFILL }},
     { &hf_owner_version,
       { "Session Version",
         "sdp.owner.version",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session Version", HFILL }},
+        NULL, HFILL }},
     { &hf_owner_network_type,
       { "Owner Network Type",
         "sdp.owner.network_type",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Owner Network Type", HFILL }},
+        NULL, HFILL }},
     { &hf_owner_address_type,
       { "Owner Address Type",
         "sdp.owner.address_type",FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1764,31 +1807,31 @@ proto_register_sdp(void)
     { &hf_owner_address,
       { "Owner Address",
         "sdp.owner.address",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Owner Address", HFILL }},
+        NULL, HFILL }},
     { &hf_connection_info_network_type,
       { "Connection Network Type",
         "sdp.connection_info.network_type",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Connection Network Type", HFILL }},
+        NULL, HFILL }},
     { &hf_connection_info_address_type,
       { "Connection Address Type",
         "sdp.connection_info.address_type",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Connection Address Type", HFILL }},
+        NULL, HFILL }},
     { &hf_connection_info_connection_address,
       { "Connection Address",
         "sdp.connection_info.address",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Connection Address", HFILL }},
+        NULL, HFILL }},
     { &hf_connection_info_ttl,
       { "Connection TTL",
         "sdp.connection_info.ttl",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Connection TTL", HFILL }},
+        NULL, HFILL }},
     { &hf_connection_info_num_addr,
       { "Connection Number of Addresses",
         "sdp.connection_info.num_addr",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Connection Number of Addresses", HFILL }},
+        NULL, HFILL }},
     { &hf_bandwidth_modifier,
       { "Bandwidth Modifier",
         "sdp.bandwidth.modifier",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Bandwidth Modifier", HFILL }},
+        NULL, HFILL }},
     { &hf_bandwidth_value,
       { "Bandwidth Value",
         "sdp.bandwidth.value",FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1796,7 +1839,7 @@ proto_register_sdp(void)
     { &hf_time_start,
       { "Session Start Time",
         "sdp.time.start",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session Start Time", HFILL }},
+        NULL, HFILL }},
     { &hf_time_stop,
       { "Session Stop Time",
         "sdp.time.stop",FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1804,67 +1847,67 @@ proto_register_sdp(void)
     { &hf_repeat_time_interval,
       { "Repeat Interval",
         "sdp.repeat_time.interval",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Repeat Interval", HFILL }},
+        NULL, HFILL }},
     { &hf_repeat_time_duration,
       { "Repeat Duration",
         "sdp.repeat_time.duration",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Repeat Duration", HFILL }},
+        NULL, HFILL }},
     { &hf_repeat_time_offset,
       { "Repeat Offset",
         "sdp.repeat_time.offset",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Repeat Offset", HFILL }},
+        NULL, HFILL }},
     { &hf_timezone_time,
       { "Timezone Time",
         "sdp.timezone.time",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Timezone Time", HFILL }},
+        NULL, HFILL }},
     { &hf_timezone_offset,
       { "Timezone Offset",
         "sdp.timezone.offset",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Timezone Offset", HFILL }},
+        NULL, HFILL }},
     { &hf_encryption_key_type,
       { "Key Type",
         "sdp.encryption_key.type",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Type", HFILL }},
+        NULL, HFILL }},
     { &hf_encryption_key_data,
       { "Key Data",
         "sdp.encryption_key.data",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Data", HFILL }},
+        NULL, HFILL }},
     { &hf_session_attribute_field,
       { "Session Attribute Fieldname",
         "sdp.session_attr.field",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session Attribute Fieldname", HFILL }},
+        NULL, HFILL }},
     { &hf_session_attribute_value,
       { "Session Attribute Value",
         "sdp.session_attr.value",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Session Attribute Value", HFILL }},
+        NULL, HFILL }},
     { &hf_media_media,
       { "Media Type",
         "sdp.media.media",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Type", HFILL }},
+        NULL, HFILL }},
     { &hf_media_port,
       { "Media Port",
         "sdp.media.port",FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Media Port", HFILL }},
+        NULL, HFILL }},
     { &hf_media_portcount,
       { "Media Port Count",
         "sdp.media.portcount",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Port Count", HFILL }},
+        NULL, HFILL }},
     { &hf_media_proto,
-      { "Media Proto",
+      { "Media Protocol",
         "sdp.media.proto",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Protocol", HFILL }},
+        NULL, HFILL }},
     { &hf_media_format,
       { "Media Format",
         "sdp.media.format",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Format", HFILL }},
+        NULL, HFILL }},
     { &hf_media_attribute_field,
       { "Media Attribute Fieldname",
         "sdp.media_attribute.field",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Attribute Fieldname", HFILL }},
+        NULL, HFILL }},
     { &hf_media_attribute_value,
       { "Media Attribute Value",
         "sdp.media_attribute.value",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Media Attribute Value", HFILL }},
+        NULL, HFILL }},
     { &hf_media_encoding_name,
       { "MIME Type",
         "sdp.mime.type",FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1872,7 +1915,7 @@ proto_register_sdp(void)
 	{ &hf_media_sample_rate,
       { "Sample Rate",
         "sdp.sample_rate",FT_STRING, BASE_NONE, NULL, 0x0,
-        "Sample Rate", HFILL }},
+        NULL, HFILL }},
     { &hf_media_format_specific_parameter,
       { "Media format specific parameters",
         "sdp.fmtp.parameter",FT_STRING, BASE_NONE, NULL, 0x0,
@@ -1880,43 +1923,47 @@ proto_register_sdp(void)
     { &hf_ipbcp_version,
       { "IPBCP Protocol Version",
         "ipbcp.version",FT_STRING, BASE_NONE, NULL, 0x0,
-        "IPBCP Protocol Version", HFILL }},
+        NULL, HFILL }},
     { &hf_ipbcp_type,
       { "IPBCP Command Type",
         "ipbcp.command",FT_STRING, BASE_NONE, NULL, 0x0,
-        "IPBCP Command Type", HFILL }},
+        NULL, HFILL }},
 	{&hf_sdp_fmtp_mpeg4_profile_level_id,
       { "Level Code",
         "sdp.fmtp.profile_level_id",FT_UINT32, BASE_DEC,VALS(mp4ves_level_indication_vals), 0x0,
-        "Level Code", HFILL }},
+        NULL, HFILL }},
 	{ &hf_sdp_fmtp_h263_profile,
       { "Profile",
         "sdp.fmtp.h263profile",FT_UINT32, BASE_DEC,VALS(h263_profile_vals), 0x0,
-        "Profile", HFILL }},
+        NULL, HFILL }},
+	{ &hf_sdp_fmtp_h263_level,
+      { "Level",
+        "sdp.fmtp.h263level",FT_UINT32, BASE_DEC,VALS(h263_level_vals), 0x0,
+        NULL, HFILL }},
 	{ &hf_sdp_h264_packetization_mode,
       { "Packetization mode",
         "sdp.fmtp.h264_packetization_mode",FT_UINT32, BASE_DEC,VALS(h264_packetization_mode_vals), 0x0,
-        "Packetization mode", HFILL }},
+        NULL, HFILL }},
 	{ &hf_sdp_h264_sprop_parameter_sets,
       { "Sprop_parameter_sets",
         "sdp.h264.sprop_parameter_sets", FT_BYTES, BASE_NONE, NULL, 0x0,
-        "Sprop_parameter_sets", HFILL }},
+        NULL, HFILL }},
     { &hf_SDPh223LogicalChannelParameters,
       { "h223LogicalChannelParameters", "sdp.h223LogicalChannelParameters",
         FT_NONE, BASE_NONE, NULL, 0,
-        "sdp.h223LogicalChannelParameters", HFILL }},
+        NULL, HFILL }},
     { &hf_key_mgmt_att_value,
       { "Key Management",
         "sdp.key_mgmt", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Key Management", HFILL }},
+        NULL, HFILL }},
     { &hf_key_mgmt_prtcl_id,
       { "Key Management Protocol (kmpid)",
         "sdp.key_mgmt.kmpid", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Key Management Protocol", HFILL }},
+        NULL, HFILL }},
     { &hf_key_mgmt_data,
       { "Key Management Data",
         "sdp.key_mgmt.data", FT_BYTES, BASE_NONE, NULL, 0x0,
-        "Key Management Data", HFILL }},
+        NULL, HFILL }},
   };
   static gint *ett[] = {
     &ett_sdp,
