@@ -3,7 +3,7 @@
  *
  * (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: oids.c 27753 2009-03-17 15:34:18Z wmeier $
+ * $Id: oids.c 30952 2009-11-13 17:58:16Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -547,20 +547,17 @@ void register_mibs(void) {
 		return;
 	}
 
+	smi_errors = g_string_new("");
+	smiSetErrorHandler(smi_error_handler);
+
 	path_str = oid_get_default_mib_path();
 	D(1,("SMI Path: '%s'",path_str));
 
 	smiSetPath(path_str);
 
-
-
-	smi_errors = g_string_new("");
-	smiSetErrorHandler(smi_error_handler);
-
 	for(i=0;i<num_smi_modules;i++) {
 		if (!smi_modules[i].name) continue;
 
-
 		if (smiIsLoaded(smi_modules[i].name)) {
 			continue;
 		} else {
@@ -1080,6 +1077,12 @@ oid_get_default_mib_path(void) {
 #else
 #define PATH_SEPARATOR ":"
 	path = smiGetPath();
+#ifdef __APPLE__
+	g_string_append(path_str, "/usr/share/snmp/mibs");
+	if (strlen(path) > 0 ) {
+		g_string_append(path_str, PATH_SEPARATOR);
+	}
+#endif
 	g_string_append_printf(path_str, "%s", path);
 	free (path);
 #endif
