@@ -2,7 +2,7 @@
  * Definitions for implementation of preference handling routines;
  * used by "friends" of the preferences type.
  *
- * $Id: prefs-int.h 21066 2007-03-19 19:08:22Z gal $
+ * $Id: prefs-int.h 23738 2007-12-04 03:28:04Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,7 @@ struct pref_module {
 	const char *description;/* Description of module (displayed in preferences notebook) */
 	void (*apply_cb)(void);	/* routine to call when preferences applied */
 	GList	*prefs;		/* list of its preferences */
-	GList	*submodules;	/* list of its submodules */
+	emem_tree_t *submodules;/* list of its submodules */
 	int	numprefs;	/* number of non-obsolete preferences */
 	gboolean prefs_changed;	/* if TRUE, a preference has changed since we last checked */
 	gboolean obsolete;	/* if TRUE, this is a module that used to
