@@ -1,7 +1,7 @@
 /* strutil.c
  * String utility routines
  *
- * $Id: strutil.c 27478 2009-02-17 23:15:35Z gerald $
+ * $Id: strutil.c 27999 2009-04-08 16:50:20Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -126,7 +126,7 @@ get_token_len(const guchar *linep, const guchar *lineend,
    */
   while (linep < lineend && *linep != ' ' && *linep != '\r' && *linep != '\n')
       linep++;
-  token_len = linep - tokenp;
+  token_len = (int) (linep - tokenp);
 
   /*
    * Skip trailing blanks.
@@ -162,7 +162,7 @@ get_token_len(const guchar *linep, const guchar *lineend,
  * characters as C-style escapes, and return a pointer to it.
  */
 gchar *
-format_text(const guchar *string, int len)
+format_text(const guchar *string, size_t len)
 {
   static gchar *fmtbuf[3];
   static int fmtbuf_len[3];
@@ -268,7 +268,7 @@ format_text(const guchar *string, int len)
  * which will be replaced by a space, and return a pointer to it.
  */
 gchar *
-format_text_wsp(const guchar *string, int len)
+format_text_wsp(const guchar *string, size_t len)
 {
   static gchar *fmtbuf[3];
   static int fmtbuf_len[3];
