@@ -1,7 +1,7 @@
 /*
  *  uat.c
  *
- * $Id: uat.c 27664 2009-03-08 22:36:43Z stig $
+ * $Id: uat.c 28093 2009-04-20 18:34:06Z guy $
  *
  *  User Accessible Tables
  *  Mantain an array of user accessible data strucures
@@ -92,7 +92,7 @@ uat_t* uat_new(const char* name,
 	uat->update_cb = update_cb;
 	uat->free_cb = free_cb;
 	uat->fields = flds_array;
-	uat->user_data = g_array_new(FALSE,FALSE,uat->record_size);
+	uat->user_data = g_array_new(FALSE,FALSE,(guint)uat->record_size);
 	uat->changed = FALSE;
 	uat->loaded = FALSE;
 	uat->rep = NULL;
@@ -126,7 +126,7 @@ void* uat_add_record(uat_t* uat, const void* data) {
 	rec = uat->user_data->data + (uat->record_size * (uat->user_data->len-1));
 
 	if (uat->copy_cb) {
-		uat->copy_cb(rec, data, uat->record_size);
+		uat->copy_cb(rec, data, (unsigned int) uat->record_size);
 	}
 
 	UAT_UPDATE(uat);
@@ -135,7 +135,7 @@ void* uat_add_record(uat_t* uat, const void* data) {
 }
 
 void uat_swap(uat_t* uat, guint a, guint b) {
-	guint s = uat->record_size;
+	size_t s = uat->record_size;
 	void* tmp = ep_alloc(s);
 
 	g_assert( a < uat->user_data->len && b < uat->user_data->len );
@@ -326,14 +326,14 @@ void uat_clear(uat_t* uat) {
 }
 
 void* uat_dup(uat_t* uat, guint* len_p) {
-	guint size = (uat->record_size * uat->user_data->len);
+	guint size = (guint) (uat->record_size * uat->user_data->len);
 	*len_p = size;
 	return size ? g_memdup(uat->user_data->data,size) : NULL ;
 }
 
 void* uat_se_dup(uat_t* uat, guint* len_p) {
-	guint size = (uat->record_size * uat->user_data->len);
-	*len_p = size;
+	guint size = (guint) (uat->record_size * uat->user_data->len);
+	*len_p = (guint) size;
 	return size ? se_memdup(uat->user_data->data,size) : NULL ;
 }
 
@@ -386,7 +386,7 @@ void uat_load_all(void) {
 }
 
 
-gboolean uat_fld_chk_str(void* u1 _U_, const char* strptr, unsigned len _U_, void* u2 _U_, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_str(void* u1 _U_, const char* strptr, unsigned len _U_, const void* u2 _U_, const void* u3 _U_, const char** err) {
 	if (strptr == NULL) {
 		*err = "NULL pointer";
 		return FALSE;
@@ -396,7 +396,7 @@ gboolean uat_fld_chk_str(void* u1 _U_, const char* strptr, unsigned len _U_, voi
 	return TRUE;
 }
 
-gboolean uat_fld_chk_proto(void* u1 _U_, const char* strptr, unsigned len, void* u2 _U_, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_proto(void* u1 _U_, const char* strptr, unsigned len, const void* u2 _U_, const void* u3 _U_, const char** err) {
 	if (len) {
 		char* name = ep_strndup(strptr,len);
 		ascii_strdown_inplace(name);
@@ -415,7 +415,7 @@ gboolean uat_fld_chk_proto(void* u1 _U_, const char* strptr, unsigned len, void*
 	}
 }
 
-gboolean uat_fld_chk_num_dec(void* u1 _U_, const char* strptr, unsigned len, void* u2 _U_, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_num_dec(void* u1 _U_, const char* strptr, unsigned len, const void* u2 _U_, const void* u3 _U_, const char** err) {
     if (len > 0) {
         char* str = ep_strndup(strptr,len);
         long i = strtol(str,&str,10);
@@ -430,7 +430,7 @@ gboolean uat_fld_chk_num_dec(void* u1 _U_, const char* strptr, unsigned len, voi
 	return TRUE;
 }
 
-gboolean uat_fld_chk_num_hex(void* u1 _U_, const char* strptr, unsigned len, void* u2 _U_, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_num_hex(void* u1 _U_, const char* strptr, unsigned len, const void* u2 _U_, const void* u3 _U_, const char** err) {
     if (len > 0) {
         char* str = ep_strndup(strptr,len);
         long i = strtol(str,&str,16);
@@ -445,10 +445,10 @@ gboolean uat_fld_chk_num_hex(void* u1 _U_, const char* strptr, unsigned len, voi
 	return TRUE;
 }
 
-gboolean uat_fld_chk_enum(void* u1 _U_, const char* strptr, unsigned len, void* v, void* u3 _U_, const char** err) {
+gboolean uat_fld_chk_enum(void* u1 _U_, const char* strptr, unsigned len, const void* v, const void* u3 _U_, const char** err) {
 	char* str = ep_strndup(strptr,len);
 	guint i;
-	value_string* vs = v;
+	const value_string* vs = v;
 
 	for(i=0;vs[i].strptr;i++) {
 		if (g_str_equal(vs[i].strptr,str)) {
@@ -461,7 +461,7 @@ gboolean uat_fld_chk_enum(void* u1 _U_, const char* strptr, unsigned len, void*
 	return FALSE;
 }
 
-gboolean uat_fld_chk_range(void* u1 _U_, const char* strptr, unsigned len, void* v _U_, void* u3, const char** err) {
+gboolean uat_fld_chk_range(void* u1 _U_, const char* strptr, unsigned len, const void* v _U_, const void* u3, const char** err) {
 	char* str = ep_strndup(strptr,len);
 	range_t* r = NULL;
 	convert_ret_t ret = range_convert_str(&r, str,GPOINTER_TO_UINT(u3));
