@@ -1,5 +1,5 @@
 /* Driver template for the LEMON parser generator.
-* $Id: lempar.c 25858 2008-07-29 12:40:03Z etxrab $
+* $Id: lempar.c 28662 2009-06-08 15:37:46Z gerald $
 *
 ** Copyright 1991-1995 by D. Richard Hipp.
 **
@@ -274,6 +274,7 @@ typedef union {
   float yy255;
   gop_tree_mode_t yy256;
   avpl_match_mode yy274;
+  int yy275;
 } YYMINORTYPE;
 #ifndef YYSTACKDEPTH
 #define YYSTACKDEPTH 100
@@ -284,6 +285,8 @@ typedef union {
 #define MateParserARG_STORE yypParser->mc  = mc 
 #define YYNSTATE 282
 #define YYNRULE 147
+#define YYERRORSYMBOL 62
+#define YYERRSYMDT yy275
 #define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
 #define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
 #define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)
@@ -895,7 +898,7 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
 {
 #line 181 "./mate_grammar.lemon"
  if ((yypminor->yy0)) g_free((yypminor->yy0)); 
-#line 902 "mate_grammar.c"
+#line 905 "mate_grammar.c"
 }
       break;
     default:  break;   /* If no destructor action specified: do nothing */
@@ -1354,7 +1357,7 @@ static void yy_reduce(
 #line 249 "./mate_grammar.lemon"
 {
 }
-#line 1360 "mate_grammar.c"
+#line 1363 "mate_grammar.c"
         break;
       case 9: /* decl ::= DONE_KW SEMICOLON */
 #line 260 "./mate_grammar.lemon"
@@ -1362,7 +1365,7 @@ static void yy_reduce(
   yy_destructor(1,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1368 "mate_grammar.c"
+#line 1371 "mate_grammar.c"
         break;
       case 10: /* debug_decl ::= DEBUG_KW OPEN_BRACE dbgfile_default dbglevel_default pdu_dbglevel_default gop_dbglevel_default gog_dbglevel_default CLOSE_BRACE SEMICOLON */
 #line 265 "./mate_grammar.lemon"
@@ -1372,28 +1375,28 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1378 "mate_grammar.c"
+#line 1381 "mate_grammar.c"
         break;
       case 11: /* dbgfile_default ::= FILENAME_KW QUOTED SEMICOLON */
 #line 267 "./mate_grammar.lemon"
 { mc->dbg_facility = ws_fopen(yymsp[-1].minor.yy0,"w"); if (mc->dbg_facility == NULL) report_open_failure(yymsp[-1].minor.yy0,errno,TRUE);   yy_destructor(6,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1385 "mate_grammar.c"
+#line 1388 "mate_grammar.c"
         break;
       case 12: /* dbgfile_default ::= FILENAME_KW NAME SEMICOLON */
 #line 268 "./mate_grammar.lemon"
 { mc->dbg_facility = ws_fopen(yymsp[-1].minor.yy0,"w"); if (mc->dbg_facility == NULL) report_open_failure(yymsp[-1].minor.yy0,errno,TRUE);    yy_destructor(6,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1392 "mate_grammar.c"
+#line 1395 "mate_grammar.c"
         break;
       case 14: /* dbglevel_default ::= LEVEL_KW INTEGER SEMICOLON */
 #line 271 "./mate_grammar.lemon"
 { mc->dbg_lvl = (int) strtol(yymsp[-1].minor.yy0,NULL,10);   yy_destructor(9,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1399 "mate_grammar.c"
+#line 1402 "mate_grammar.c"
         break;
       case 16: /* pdu_dbglevel_default ::= PDU_KW LEVEL_KW INTEGER SEMICOLON */
 #line 274 "./mate_grammar.lemon"
@@ -1401,7 +1404,7 @@ static void yy_reduce(
   yy_destructor(9,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1407 "mate_grammar.c"
+#line 1410 "mate_grammar.c"
         break;
       case 18: /* gop_dbglevel_default ::= GOP_KW LEVEL_KW INTEGER SEMICOLON */
 #line 277 "./mate_grammar.lemon"
@@ -1409,7 +1412,7 @@ static void yy_reduce(
   yy_destructor(9,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1415 "mate_grammar.c"
+#line 1418 "mate_grammar.c"
         break;
       case 20: /* gog_dbglevel_default ::= GOG_KW LEVEL_KW INTEGER SEMICOLON */
 #line 280 "./mate_grammar.lemon"
@@ -1417,7 +1420,7 @@ static void yy_reduce(
   yy_destructor(9,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1423 "mate_grammar.c"
+#line 1426 "mate_grammar.c"
         break;
       case 22: /* defaults_decl ::= DEFAULT_KW OPEN_BRACE pdu_defaults gop_defaults gog_defaults CLOSE_BRACE SEMICOLON */
 #line 287 "./mate_grammar.lemon"
@@ -1427,7 +1430,7 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1433 "mate_grammar.c"
+#line 1436 "mate_grammar.c"
         break;
       case 23: /* pdu_defaults ::= PDU_KW OPEN_BRACE pdu_last_extracted_default pdu_drop_unassigned_default pdu_discard_default CLOSE_BRACE SEMICOLON */
 #line 289 "./mate_grammar.lemon"
@@ -1437,28 +1440,28 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1443 "mate_grammar.c"
+#line 1446 "mate_grammar.c"
         break;
       case 25: /* pdu_last_extracted_default ::= LAST_EXTRACTED_KW true_false SEMICOLON */
 #line 292 "./mate_grammar.lemon"
 { mc->defaults.pdu.last_extracted = yymsp[-1].minor.yy182;   yy_destructor(15,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1450 "mate_grammar.c"
+#line 1453 "mate_grammar.c"
         break;
       case 27: /* pdu_drop_unassigned_default ::= DROP_UNASSIGNED_KW true_false SEMICOLON */
 #line 295 "./mate_grammar.lemon"
 { mc->defaults.pdu.drop_unassigned = yymsp[-1].minor.yy182;   yy_destructor(16,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1457 "mate_grammar.c"
+#line 1460 "mate_grammar.c"
         break;
       case 29: /* pdu_discard_default ::= DISCARD_PDU_DATA_KW true_false SEMICOLON */
 #line 298 "./mate_grammar.lemon"
 { mc->defaults.pdu.discard = yymsp[-1].minor.yy182;   yy_destructor(17,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1464 "mate_grammar.c"
+#line 1467 "mate_grammar.c"
         break;
       case 31: /* gop_defaults ::= GOP_KW OPEN_BRACE gop_expiration_default gop_idle_timeout_default gop_lifetime_default gop_drop_unassigned_default gop_tree_mode_default gop_show_times_default CLOSE_BRACE SEMICOLON */
 #line 301 "./mate_grammar.lemon"
@@ -1468,7 +1471,7 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1474 "mate_grammar.c"
+#line 1477 "mate_grammar.c"
         break;
       case 33: /* gop_expiration_default ::= EXPIRATION_KW time_value SEMICOLON */
       case 47: /* gog_expiration_default ::= EXPIRATION_KW time_value SEMICOLON */
@@ -1476,42 +1479,42 @@ static void yy_reduce(
 { mc->defaults.gop.expiration = yymsp[-1].minor.yy255;   yy_destructor(18,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1482 "mate_grammar.c"
+#line 1485 "mate_grammar.c"
         break;
       case 35: /* gop_idle_timeout_default ::= IDLE_TIMEOUT_KW time_value SEMICOLON */
 #line 307 "./mate_grammar.lemon"
 { mc->defaults.gop.idle_timeout = yymsp[-1].minor.yy255;   yy_destructor(19,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1489 "mate_grammar.c"
+#line 1492 "mate_grammar.c"
         break;
       case 37: /* gop_lifetime_default ::= LIFETIME_KW time_value SEMICOLON */
 #line 310 "./mate_grammar.lemon"
 { mc->defaults.gop.lifetime = yymsp[-1].minor.yy255;   yy_destructor(20,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1496 "mate_grammar.c"
+#line 1499 "mate_grammar.c"
         break;
       case 39: /* gop_drop_unassigned_default ::= DROP_UNASSIGNED_KW true_false SEMICOLON */
 #line 313 "./mate_grammar.lemon"
 { mc->defaults.gop.drop_unassigned = yymsp[-1].minor.yy182;   yy_destructor(16,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1503 "mate_grammar.c"
+#line 1506 "mate_grammar.c"
         break;
       case 41: /* gop_tree_mode_default ::= SHOW_TREE_KW gop_tree_mode SEMICOLON */
 #line 316 "./mate_grammar.lemon"
 { mc->defaults.gop.pdu_tree_mode = yymsp[-1].minor.yy256;   yy_destructor(21,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1510 "mate_grammar.c"
+#line 1513 "mate_grammar.c"
         break;
       case 43: /* gop_show_times_default ::= SHOW_TIMES_KW true_false SEMICOLON */
 #line 319 "./mate_grammar.lemon"
 { mc->defaults.gop.show_times = yymsp[-1].minor.yy182;   yy_destructor(22,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1517 "mate_grammar.c"
+#line 1520 "mate_grammar.c"
         break;
       case 45: /* gog_defaults ::= GOG_KW OPEN_BRACE gog_expiration_default gop_tree_mode_default gog_goptree_default CLOSE_BRACE SEMICOLON */
 #line 322 "./mate_grammar.lemon"
@@ -1521,14 +1524,14 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1527 "mate_grammar.c"
+#line 1530 "mate_grammar.c"
         break;
       case 49: /* gog_goptree_default ::= GOP_TREE_KW gop_tree_type SEMICOLON */
 #line 328 "./mate_grammar.lemon"
 { mc->defaults.gog.gop_tree_mode = yymsp[-1].minor.yy256;   yy_destructor(23,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1534 "mate_grammar.c"
+#line 1537 "mate_grammar.c"
         break;
       case 51: /* transform_decl ::= TRANSFORM_KW NAME transform_body SEMICOLON */
 #line 335 "./mate_grammar.lemon"
@@ -1548,14 +1551,14 @@ static void yy_reduce(
   yy_destructor(24,&yymsp[-3].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1554 "mate_grammar.c"
+#line 1557 "mate_grammar.c"
         break;
       case 52: /* transform_body ::= OPEN_BRACE transform_statements CLOSE_BRACE */
 #line 350 "./mate_grammar.lemon"
 { yygotominor.yy11 = yymsp[-1].minor.yy11;   yy_destructor(4,&yymsp[-2].minor);
   yy_destructor(5,&yymsp[0].minor);
 }
-#line 1561 "mate_grammar.c"
+#line 1564 "mate_grammar.c"
         break;
       case 53: /* transform_statements ::= transform_statements transform_statement */
 #line 352 "./mate_grammar.lemon"
@@ -1566,12 +1569,12 @@ static void yy_reduce(
 	c->next = yymsp[0].minor.yy11;
 	yygotominor.yy11 = yymsp[-1].minor.yy11;
 }
-#line 1572 "mate_grammar.c"
+#line 1575 "mate_grammar.c"
         break;
       case 54: /* transform_statements ::= transform_statement */
 #line 360 "./mate_grammar.lemon"
 { yygotominor.yy11 = yymsp[0].minor.yy11; }
-#line 1577 "mate_grammar.c"
+#line 1580 "mate_grammar.c"
         break;
       case 55: /* transform_statement ::= transform_match transform_action SEMICOLON */
 #line 362 "./mate_grammar.lemon"
@@ -1579,7 +1582,7 @@ static void yy_reduce(
 	yygotominor.yy11 = new_transform_elem(yymsp[-2].minor.yy146->avpl,yymsp[-1].minor.yy85->avpl,yymsp[-2].minor.yy146->match_mode,yymsp[-1].minor.yy85->replace_mode);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1585 "mate_grammar.c"
+#line 1588 "mate_grammar.c"
         break;
       case 56: /* transform_match ::= MATCH_KW match_mode avpl */
 #line 366 "./mate_grammar.lemon"
@@ -1589,7 +1592,7 @@ static void yy_reduce(
     yygotominor.yy146->avpl = yymsp[0].minor.yy70;
   yy_destructor(25,&yymsp[-2].minor);
 }
-#line 1595 "mate_grammar.c"
+#line 1598 "mate_grammar.c"
         break;
       case 57: /* transform_match ::= */
 #line 372 "./mate_grammar.lemon"
@@ -1599,7 +1602,7 @@ static void yy_reduce(
     yygotominor.yy146->avpl = new_avpl("");
 
 }
-#line 1605 "mate_grammar.c"
+#line 1608 "mate_grammar.c"
         break;
       case 58: /* transform_action ::= */
 #line 379 "./mate_grammar.lemon"
@@ -1608,7 +1611,7 @@ static void yy_reduce(
     yygotominor.yy85->replace_mode = AVPL_INSERT;
     yygotominor.yy85->avpl = new_avpl("");
 }
-#line 1614 "mate_grammar.c"
+#line 1617 "mate_grammar.c"
         break;
       case 59: /* transform_action ::= action_mode avpl */
 #line 384 "./mate_grammar.lemon"
@@ -1617,47 +1620,47 @@ static void yy_reduce(
     yygotominor.yy85->replace_mode = yymsp[-1].minor.yy143;
     yygotominor.yy85->avpl = yymsp[0].minor.yy70;
 }
-#line 1623 "mate_grammar.c"
+#line 1626 "mate_grammar.c"
         break;
       case 60: /* match_mode ::= */
 #line 390 "./mate_grammar.lemon"
 { yygotominor.yy274 = AVPL_STRICT; }
-#line 1628 "mate_grammar.c"
+#line 1631 "mate_grammar.c"
         break;
       case 61: /* match_mode ::= STRICT_KW */
 #line 391 "./mate_grammar.lemon"
 { yygotominor.yy274 = AVPL_STRICT;   yy_destructor(26,&yymsp[0].minor);
 }
-#line 1634 "mate_grammar.c"
+#line 1637 "mate_grammar.c"
         break;
       case 62: /* match_mode ::= EVERY_KW */
 #line 392 "./mate_grammar.lemon"
 { yygotominor.yy274 = AVPL_EVERY;   yy_destructor(27,&yymsp[0].minor);
 }
-#line 1640 "mate_grammar.c"
+#line 1643 "mate_grammar.c"
         break;
       case 63: /* match_mode ::= LOOSE_KW */
 #line 393 "./mate_grammar.lemon"
 { yygotominor.yy274 = AVPL_LOOSE;   yy_destructor(28,&yymsp[0].minor);
 }
-#line 1646 "mate_grammar.c"
+#line 1649 "mate_grammar.c"
         break;
       case 64: /* action_mode ::= REPLACE_KW */
 #line 395 "./mate_grammar.lemon"
 { yygotominor.yy143 = AVPL_REPLACE;   yy_destructor(29,&yymsp[0].minor);
 }
-#line 1652 "mate_grammar.c"
+#line 1655 "mate_grammar.c"
         break;
       case 65: /* action_mode ::= INSERT_KW */
 #line 396 "./mate_grammar.lemon"
 { yygotominor.yy143 = AVPL_INSERT;   yy_destructor(30,&yymsp[0].minor);
 }
-#line 1658 "mate_grammar.c"
+#line 1661 "mate_grammar.c"
         break;
       case 66: /* action_mode ::= */
 #line 397 "./mate_grammar.lemon"
 { yygotominor.yy143 = AVPL_INSERT; }
-#line 1663 "mate_grammar.c"
+#line 1666 "mate_grammar.c"
         break;
       case 67: /* pdu_decl ::= PDU_KW NAME PROTO_KW field TRANSPORT_KW proto_stack OPEN_BRACE payload_statement extraction_statements transform_list_statement criteria_statement pdu_drop_unassigned_statement discard_pdu_data_statement last_extracted_statement CLOSE_BRACE SEMICOLON */
 #line 413 "./mate_grammar.lemon"
@@ -1712,24 +1715,24 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1718 "mate_grammar.c"
+#line 1721 "mate_grammar.c"
         break;
       case 68: /* payload_statement ::= */
 #line 459 "./mate_grammar.lemon"
 { yygotominor.yy147 = NULL; }
-#line 1723 "mate_grammar.c"
+#line 1726 "mate_grammar.c"
         break;
       case 69: /* payload_statement ::= PAYLOAD_KW proto_stack SEMICOLON */
 #line 460 "./mate_grammar.lemon"
 { yygotominor.yy147 = yymsp[-1].minor.yy147;   yy_destructor(33,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1730 "mate_grammar.c"
+#line 1733 "mate_grammar.c"
         break;
       case 70: /* criteria_statement ::= */
 #line 462 "./mate_grammar.lemon"
 { yygotominor.yy231 = NULL; }
-#line 1735 "mate_grammar.c"
+#line 1738 "mate_grammar.c"
         break;
       case 71: /* criteria_statement ::= CRITERIA_KW accept_mode match_mode avpl SEMICOLON */
 #line 463 "./mate_grammar.lemon"
@@ -1741,34 +1744,34 @@ static void yy_reduce(
   yy_destructor(34,&yymsp[-4].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1747 "mate_grammar.c"
+#line 1750 "mate_grammar.c"
         break;
       case 72: /* accept_mode ::= */
 #line 470 "./mate_grammar.lemon"
 { yygotominor.yy148 = ACCEPT_MODE; }
-#line 1752 "mate_grammar.c"
+#line 1755 "mate_grammar.c"
         break;
       case 73: /* accept_mode ::= ACCEPT_KW */
 #line 471 "./mate_grammar.lemon"
 { yygotominor.yy148 = ACCEPT_MODE;   yy_destructor(35,&yymsp[0].minor);
 }
-#line 1758 "mate_grammar.c"
+#line 1761 "mate_grammar.c"
         break;
       case 74: /* accept_mode ::= REJECT_KW */
 #line 472 "./mate_grammar.lemon"
 { yygotominor.yy148 = REJECT_MODE;   yy_destructor(36,&yymsp[0].minor);
 }
-#line 1764 "mate_grammar.c"
+#line 1767 "mate_grammar.c"
         break;
       case 75: /* extraction_statements ::= extraction_statements extraction_statement */
 #line 474 "./mate_grammar.lemon"
 { yygotominor.yy179 = yymsp[-1].minor.yy179; yygotominor.yy179->last = yygotominor.yy179->last->next = yymsp[0].minor.yy179; }
-#line 1769 "mate_grammar.c"
+#line 1772 "mate_grammar.c"
         break;
       case 76: /* extraction_statements ::= extraction_statement */
 #line 475 "./mate_grammar.lemon"
 { yygotominor.yy179 = yymsp[0].minor.yy179; yygotominor.yy179->last = yygotominor.yy179; }
-#line 1774 "mate_grammar.c"
+#line 1777 "mate_grammar.c"
         break;
       case 77: /* extraction_statement ::= EXTRACT_KW NAME FROM_KW field SEMICOLON */
 #line 477 "./mate_grammar.lemon"
@@ -1781,7 +1784,7 @@ static void yy_reduce(
   yy_destructor(38,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1787 "mate_grammar.c"
+#line 1790 "mate_grammar.c"
         break;
       case 78: /* pdu_drop_unassigned_statement ::= DROP_UNASSIGNED_KW true_false SEMICOLON */
       case 88: /* gop_drop_unassigned_statement ::= DROP_UNASSIGNED_KW true_false SEMICOLON */
@@ -1789,36 +1792,36 @@ static void yy_reduce(
 { yygotominor.yy182 = yymsp[-1].minor.yy182;   yy_destructor(16,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1795 "mate_grammar.c"
+#line 1798 "mate_grammar.c"
         break;
       case 79: /* pdu_drop_unassigned_statement ::= */
 #line 486 "./mate_grammar.lemon"
 { yygotominor.yy182 =  mc->defaults.pdu.drop_unassigned; }
-#line 1800 "mate_grammar.c"
+#line 1803 "mate_grammar.c"
         break;
       case 80: /* discard_pdu_data_statement ::= DISCARD_PDU_DATA_KW true_false SEMICOLON */
 #line 488 "./mate_grammar.lemon"
 { yygotominor.yy182 = yymsp[-1].minor.yy182;   yy_destructor(17,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1807 "mate_grammar.c"
+#line 1810 "mate_grammar.c"
         break;
       case 81: /* discard_pdu_data_statement ::= */
 #line 489 "./mate_grammar.lemon"
 { yygotominor.yy182 =  mc->defaults.pdu.discard; }
-#line 1812 "mate_grammar.c"
+#line 1815 "mate_grammar.c"
         break;
       case 82: /* last_extracted_statement ::= LAST_PDU_KW true_false SEMICOLON */
 #line 491 "./mate_grammar.lemon"
 { yygotominor.yy182 = yymsp[-1].minor.yy182;   yy_destructor(39,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1819 "mate_grammar.c"
+#line 1822 "mate_grammar.c"
         break;
       case 83: /* last_extracted_statement ::= */
 #line 492 "./mate_grammar.lemon"
 { yygotominor.yy182 = mc->defaults.pdu.last_extracted; }
-#line 1824 "mate_grammar.c"
+#line 1827 "mate_grammar.c"
         break;
       case 84: /* proto_stack ::= proto_stack SLASH field */
 #line 494 "./mate_grammar.lemon"
@@ -1832,7 +1835,7 @@ static void yy_reduce(
 	yygotominor.yy147 = yymsp[-2].minor.yy147;
   yy_destructor(40,&yymsp[-1].minor);
 }
-#line 1838 "mate_grammar.c"
+#line 1841 "mate_grammar.c"
         break;
       case 85: /* proto_stack ::= field */
 #line 504 "./mate_grammar.lemon"
@@ -1845,14 +1848,14 @@ static void yy_reduce(
 	yygotominor.yy147 = g_ptr_array_new();
 	g_ptr_array_add(yygotominor.yy147,hfidp);
 }
-#line 1851 "mate_grammar.c"
+#line 1854 "mate_grammar.c"
         break;
       case 86: /* field ::= NAME */
 #line 514 "./mate_grammar.lemon"
 {
 	yygotominor.yy210 = proto_registrar_get_byname(yymsp[0].minor.yy0);
 }
-#line 1858 "mate_grammar.c"
+#line 1861 "mate_grammar.c"
         break;
       case 87: /* gop_decl ::= GOP_KW NAME ON_KW pdu_name MATCH_KW avpl OPEN_BRACE gop_start_statement gop_stop_statement extra_statement transform_list_statement gop_expiration_statement idle_timeout_statement lifetime_statement gop_drop_unassigned_statement show_goptree_statement show_times_statement CLOSE_BRACE SEMICOLON */
 #line 532 "./mate_grammar.lemon"
@@ -1887,56 +1890,56 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1893 "mate_grammar.c"
+#line 1896 "mate_grammar.c"
         break;
       case 89: /* gop_drop_unassigned_statement ::= */
 #line 559 "./mate_grammar.lemon"
 { yygotominor.yy182 =  mc->defaults.gop.drop_unassigned; }
-#line 1898 "mate_grammar.c"
+#line 1901 "mate_grammar.c"
         break;
       case 90: /* gop_start_statement ::= START_KW avpl SEMICOLON */
 #line 561 "./mate_grammar.lemon"
 { yygotominor.yy70 = yymsp[-1].minor.yy70;   yy_destructor(42,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1905 "mate_grammar.c"
+#line 1908 "mate_grammar.c"
         break;
       case 91: /* gop_start_statement ::= */
       case 93: /* gop_stop_statement ::= */
 #line 562 "./mate_grammar.lemon"
 { yygotominor.yy70 = NULL; }
-#line 1911 "mate_grammar.c"
+#line 1914 "mate_grammar.c"
         break;
       case 92: /* gop_stop_statement ::= STOP_KW avpl SEMICOLON */
 #line 564 "./mate_grammar.lemon"
 { yygotominor.yy70 = yymsp[-1].minor.yy70;   yy_destructor(43,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1918 "mate_grammar.c"
+#line 1921 "mate_grammar.c"
         break;
       case 94: /* show_goptree_statement ::= SHOW_TREE_KW gop_tree_mode SEMICOLON */
 #line 567 "./mate_grammar.lemon"
 { yygotominor.yy256 = yymsp[-1].minor.yy256;   yy_destructor(21,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1925 "mate_grammar.c"
+#line 1928 "mate_grammar.c"
         break;
       case 95: /* show_goptree_statement ::= */
 #line 568 "./mate_grammar.lemon"
 { yygotominor.yy256 = mc->defaults.gop.pdu_tree_mode; }
-#line 1930 "mate_grammar.c"
+#line 1933 "mate_grammar.c"
         break;
       case 96: /* show_times_statement ::= SHOW_TIMES_KW true_false SEMICOLON */
 #line 570 "./mate_grammar.lemon"
 { yygotominor.yy182 = yymsp[-1].minor.yy182;   yy_destructor(22,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1937 "mate_grammar.c"
+#line 1940 "mate_grammar.c"
         break;
       case 97: /* show_times_statement ::= */
 #line 571 "./mate_grammar.lemon"
 { yygotominor.yy182 = mc->defaults.gop.show_times; }
-#line 1942 "mate_grammar.c"
+#line 1945 "mate_grammar.c"
         break;
       case 98: /* gop_expiration_statement ::= EXPIRATION_KW time_value SEMICOLON */
       case 116: /* gog_expiration_statement ::= EXPIRATION_KW time_value SEMICOLON */
@@ -1944,64 +1947,64 @@ static void yy_reduce(
 { yygotominor.yy255 = yymsp[-1].minor.yy255;   yy_destructor(18,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1950 "mate_grammar.c"
+#line 1953 "mate_grammar.c"
         break;
       case 99: /* gop_expiration_statement ::= */
       case 101: /* idle_timeout_statement ::= */
       case 103: /* lifetime_statement ::= */
 #line 574 "./mate_grammar.lemon"
 { yygotominor.yy255 = mc->defaults.gop.lifetime; }
-#line 1957 "mate_grammar.c"
+#line 1960 "mate_grammar.c"
         break;
       case 100: /* idle_timeout_statement ::= IDLE_TIMEOUT_KW time_value SEMICOLON */
 #line 576 "./mate_grammar.lemon"
 { yygotominor.yy255 = yymsp[-1].minor.yy255;   yy_destructor(19,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1964 "mate_grammar.c"
+#line 1967 "mate_grammar.c"
         break;
       case 102: /* lifetime_statement ::= LIFETIME_KW time_value SEMICOLON */
 #line 579 "./mate_grammar.lemon"
 { yygotominor.yy255 = yymsp[-1].minor.yy255;   yy_destructor(20,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 1971 "mate_grammar.c"
+#line 1974 "mate_grammar.c"
         break;
       case 104: /* gop_tree_mode ::= NO_TREE_KW */
 #line 582 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_NO_TREE;   yy_destructor(44,&yymsp[0].minor);
 }
-#line 1977 "mate_grammar.c"
+#line 1980 "mate_grammar.c"
         break;
       case 105: /* gop_tree_mode ::= PDU_TREE_KW */
 #line 583 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_PDU_TREE;   yy_destructor(45,&yymsp[0].minor);
 }
-#line 1983 "mate_grammar.c"
+#line 1986 "mate_grammar.c"
         break;
       case 106: /* gop_tree_mode ::= FRAME_TREE_KW */
 #line 584 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_FRAME_TREE;   yy_destructor(46,&yymsp[0].minor);
 }
-#line 1989 "mate_grammar.c"
+#line 1992 "mate_grammar.c"
         break;
       case 107: /* gop_tree_mode ::= BASIC_TREE_KW */
 #line 585 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_BASIC_PDU_TREE;   yy_destructor(47,&yymsp[0].minor);
 }
-#line 1995 "mate_grammar.c"
+#line 1998 "mate_grammar.c"
         break;
       case 108: /* true_false ::= TRUE_KW */
 #line 587 "./mate_grammar.lemon"
 { yygotominor.yy182 = TRUE;   yy_destructor(48,&yymsp[0].minor);
 }
-#line 2001 "mate_grammar.c"
+#line 2004 "mate_grammar.c"
         break;
       case 109: /* true_false ::= FALSE_KW */
 #line 588 "./mate_grammar.lemon"
 { yygotominor.yy182 = FALSE;   yy_destructor(49,&yymsp[0].minor);
 }
-#line 2007 "mate_grammar.c"
+#line 2010 "mate_grammar.c"
         break;
       case 110: /* pdu_name ::= NAME */
 #line 590 "./mate_grammar.lemon"
@@ -2013,7 +2016,7 @@ static void yy_reduce(
 		configuration_error(mc,"No such Pdu: '%s'",yymsp[0].minor.yy0);
 	}
 }
-#line 2019 "mate_grammar.c"
+#line 2022 "mate_grammar.c"
         break;
       case 111: /* time_value ::= FLOATING */
       case 112: /* time_value ::= INTEGER */
@@ -2021,7 +2024,7 @@ static void yy_reduce(
 {
 	yygotominor.yy255 = (float) strtod(yymsp[0].minor.yy0,NULL);
 }
-#line 2027 "mate_grammar.c"
+#line 2030 "mate_grammar.c"
         break;
       case 113: /* gog_decl ::= GOG_KW NAME OPEN_BRACE gog_key_statements extra_statement transform_list_statement gog_expiration_statement gog_goptree_statement CLOSE_BRACE SEMICOLON */
 #line 617 "./mate_grammar.lemon"
@@ -2046,42 +2049,42 @@ static void yy_reduce(
   yy_destructor(5,&yymsp[-1].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 2052 "mate_grammar.c"
+#line 2055 "mate_grammar.c"
         break;
       case 114: /* gog_goptree_statement ::= GOP_TREE_KW gop_tree_type SEMICOLON */
 #line 635 "./mate_grammar.lemon"
 { yygotominor.yy256 = yymsp[-1].minor.yy256;   yy_destructor(23,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 2059 "mate_grammar.c"
+#line 2062 "mate_grammar.c"
         break;
       case 115: /* gog_goptree_statement ::= */
 #line 636 "./mate_grammar.lemon"
 { yygotominor.yy256 = mc->defaults.gog.gop_tree_mode; }
-#line 2064 "mate_grammar.c"
+#line 2067 "mate_grammar.c"
         break;
       case 117: /* gog_expiration_statement ::= */
 #line 639 "./mate_grammar.lemon"
 { yygotominor.yy255 = mc->defaults.gog.expiration; }
-#line 2069 "mate_grammar.c"
+#line 2072 "mate_grammar.c"
         break;
       case 118: /* gop_tree_type ::= NULL_TREE_KW */
 #line 641 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_NULL_TREE;   yy_destructor(51,&yymsp[0].minor);
 }
-#line 2075 "mate_grammar.c"
+#line 2078 "mate_grammar.c"
         break;
       case 119: /* gop_tree_type ::= FULL_TREE_KW */
 #line 642 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_FULL_TREE;   yy_destructor(52,&yymsp[0].minor);
 }
-#line 2081 "mate_grammar.c"
+#line 2084 "mate_grammar.c"
         break;
       case 120: /* gop_tree_type ::= BASIC_TREE_KW */
 #line 643 "./mate_grammar.lemon"
 { yygotominor.yy256 = GOP_BASIC_TREE;   yy_destructor(47,&yymsp[0].minor);
 }
-#line 2087 "mate_grammar.c"
+#line 2090 "mate_grammar.c"
         break;
       case 121: /* gog_key_statements ::= gog_key_statements gog_key_statement */
 #line 645 "./mate_grammar.lemon"
@@ -2089,7 +2092,7 @@ static void yy_reduce(
 	loal_append(yymsp[-1].minor.yy77,yymsp[0].minor.yy70);
 	yygotominor.yy77 = yymsp[-1].minor.yy77;
 }
-#line 2095 "mate_grammar.c"
+#line 2098 "mate_grammar.c"
         break;
       case 122: /* gog_key_statements ::= gog_key_statement */
 #line 650 "./mate_grammar.lemon"
@@ -2097,7 +2100,7 @@ static void yy_reduce(
 	yygotominor.yy77 = new_loal("");
 	loal_append(yygotominor.yy77,yymsp[0].minor.yy70);
 }
-#line 2103 "mate_grammar.c"
+#line 2106 "mate_grammar.c"
         break;
       case 123: /* gog_key_statement ::= MEMBER_KW gop_name avpl SEMICOLON */
 #line 656 "./mate_grammar.lemon"
@@ -2107,7 +2110,7 @@ static void yy_reduce(
   yy_destructor(53,&yymsp[-3].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 2113 "mate_grammar.c"
+#line 2116 "mate_grammar.c"
         break;
       case 124: /* gop_name ::= NAME */
 #line 661 "./mate_grammar.lemon"
@@ -2119,31 +2122,31 @@ static void yy_reduce(
 		configuration_error(mc,"No Gop called '%s' has been already declared",yymsp[0].minor.yy0);
 	}
 }
-#line 2125 "mate_grammar.c"
+#line 2128 "mate_grammar.c"
         break;
       case 125: /* extra_statement ::= EXTRA_KW avpl SEMICOLON */
 #line 673 "./mate_grammar.lemon"
 { yygotominor.yy70 = yymsp[-1].minor.yy70;   yy_destructor(54,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 2132 "mate_grammar.c"
+#line 2135 "mate_grammar.c"
         break;
       case 126: /* extra_statement ::= */
 #line 674 "./mate_grammar.lemon"
 { yygotominor.yy70 = new_avpl(""); }
-#line 2137 "mate_grammar.c"
+#line 2140 "mate_grammar.c"
         break;
       case 127: /* transform_list_statement ::= TRANSFORM_KW transform_list SEMICOLON */
 #line 676 "./mate_grammar.lemon"
 { yygotominor.yy147 = yymsp[-1].minor.yy147;   yy_destructor(24,&yymsp[-2].minor);
   yy_destructor(2,&yymsp[0].minor);
 }
-#line 2144 "mate_grammar.c"
+#line 2147 "mate_grammar.c"
         break;
       case 128: /* transform_list_statement ::= */
 #line 677 "./mate_grammar.lemon"
 { yygotominor.yy147 = g_ptr_array_new(); }
-#line 2149 "mate_grammar.c"
+#line 2152 "mate_grammar.c"
         break;
       case 129: /* transform_list ::= transform_list COMMA transform */
 #line 679 "./mate_grammar.lemon"
@@ -2152,7 +2155,7 @@ static void yy_reduce(
 	g_ptr_array_add(yymsp[-2].minor.yy147,yymsp[0].minor.yy11);
   yy_destructor(55,&yymsp[-1].minor);
 }
-#line 2158 "mate_grammar.c"
+#line 2161 "mate_grammar.c"
         break;
       case 130: /* transform_list ::= transform */
 #line 684 "./mate_grammar.lemon"
@@ -2160,7 +2163,7 @@ static void yy_reduce(
 	yygotominor.yy147 = g_ptr_array_new();
 	g_ptr_array_add(yygotominor.yy147,yymsp[0].minor.yy11);
 }
-#line 2166 "mate_grammar.c"
+#line 2169 "mate_grammar.c"
         break;
       case 131: /* transform ::= NAME */
 #line 689 "./mate_grammar.lemon"
@@ -2173,60 +2176,60 @@ static void yy_reduce(
 		configuration_error(mc,"There's no such Transformation: %s",yymsp[0].minor.yy0);
 	}
 }
-#line 2179 "mate_grammar.c"
+#line 2182 "mate_grammar.c"
         break;
       case 132: /* avpl ::= OPEN_PARENS avps CLOSE_PARENS */
 #line 699 "./mate_grammar.lemon"
 { yygotominor.yy70 = yymsp[-1].minor.yy70;   yy_destructor(56,&yymsp[-2].minor);
   yy_destructor(57,&yymsp[0].minor);
 }
-#line 2186 "mate_grammar.c"
+#line 2189 "mate_grammar.c"
         break;
       case 133: /* avpl ::= OPEN_PARENS CLOSE_PARENS */
 #line 700 "./mate_grammar.lemon"
 { yygotominor.yy70 = new_avpl("");   yy_destructor(56,&yymsp[-1].minor);
   yy_destructor(57,&yymsp[0].minor);
 }
-#line 2193 "mate_grammar.c"
+#line 2196 "mate_grammar.c"
         break;
       case 134: /* avps ::= avps COMMA avp */
 #line 702 "./mate_grammar.lemon"
 { yygotominor.yy70 = yymsp[-2].minor.yy70; if ( ! insert_avp(yymsp[-2].minor.yy70,yymsp[0].minor.yy226) ) delete_avp(yymsp[0].minor.yy226);   yy_destructor(55,&yymsp[-1].minor);
 }
-#line 2199 "mate_grammar.c"
+#line 2202 "mate_grammar.c"
         break;
       case 135: /* avps ::= avp */
 #line 703 "./mate_grammar.lemon"
 { yygotominor.yy70 = new_avpl(""); if ( ! insert_avp(yygotominor.yy70,yymsp[0].minor.yy226) ) delete_avp(yymsp[0].minor.yy226); }
-#line 2204 "mate_grammar.c"
+#line 2207 "mate_grammar.c"
         break;
       case 136: /* avp ::= NAME AVP_OPERATOR value */
 #line 705 "./mate_grammar.lemon"
 { yygotominor.yy226 = new_avp(yymsp[-2].minor.yy0,yymsp[0].minor.yy212,*yymsp[-1].minor.yy0); }
-#line 2209 "mate_grammar.c"
+#line 2212 "mate_grammar.c"
         break;
       case 137: /* avp ::= NAME */
 #line 706 "./mate_grammar.lemon"
 { yygotominor.yy226 = new_avp(yymsp[0].minor.yy0,"",'?'); }
-#line 2214 "mate_grammar.c"
+#line 2217 "mate_grammar.c"
         break;
       case 138: /* avp ::= NAME OPEN_BRACE avp_oneoff CLOSE_BRACE */
 #line 707 "./mate_grammar.lemon"
 { yygotominor.yy226 = new_avp(yymsp[-3].minor.yy0,yymsp[-1].minor.yy212,'|');   yy_destructor(4,&yymsp[-2].minor);
   yy_destructor(5,&yymsp[0].minor);
 }
-#line 2221 "mate_grammar.c"
+#line 2224 "mate_grammar.c"
         break;
       case 139: /* avp_oneoff ::= avp_oneoff PIPE value */
 #line 709 "./mate_grammar.lemon"
 { yygotominor.yy212 = g_strdup_printf("%s|%s",yymsp[-2].minor.yy212,yymsp[0].minor.yy212);   yy_destructor(59,&yymsp[-1].minor);
 }
-#line 2227 "mate_grammar.c"
+#line 2230 "mate_grammar.c"
         break;
       case 140: /* avp_oneoff ::= value */
 #line 710 "./mate_grammar.lemon"
 { yygotominor.yy212 = g_strdup(yymsp[0].minor.yy212); }
-#line 2232 "mate_grammar.c"
+#line 2235 "mate_grammar.c"
         break;
       case 141: /* value ::= QUOTED */
       case 142: /* value ::= NAME */
@@ -2235,12 +2238,12 @@ static void yy_reduce(
       case 145: /* value ::= DOTED_IP */
 #line 712 "./mate_grammar.lemon"
 { yygotominor.yy212 = g_strdup(yymsp[0].minor.yy0); }
-#line 2241 "mate_grammar.c"
+#line 2244 "mate_grammar.c"
         break;
       case 146: /* value ::= COLONIZED */
 #line 717 "./mate_grammar.lemon"
 { yygotominor.yy212 = recolonize(mc,yymsp[0].minor.yy0); }
-#line 2246 "mate_grammar.c"
+#line 2249 "mate_grammar.c"
         break;
   };
   yygoto = yyRuleInfo[yyruleno].lhs;
@@ -2288,7 +2291,7 @@ static void yy_parse_failed(
 #line 189 "./mate_grammar.lemon"
 
 	configuration_error(mc,"Parse Error");
-#line 2296 "mate_grammar.c"
+#line 2299 "mate_grammar.c"
   MateParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
 }
 
@@ -2305,7 +2308,7 @@ static void yy_syntax_error(
 #line 185 "./mate_grammar.lemon"
 
 	configuration_error(mc,"Syntax Error before %s",yyminor);
-#line 2315 "mate_grammar.c"
+#line 2318 "mate_grammar.c"
   MateParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
 }
 
@@ -2396,10 +2399,10 @@ void MateParser(
     }else if( yyact < YYNSTATE + YYNRULE ){
       yy_reduce(yypParser,yyact-YYNSTATE);
     }else{
-      assert( yyact == YY_ERROR_ACTION );
 #ifdef YYERRORSYMBOL
       int yymx;
 #endif
+      assert( yyact == YY_ERROR_ACTION );
 #ifndef NDEBUG
       if( yyTraceFILE ){
         fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
