@@ -1,6 +1,6 @@
 /* wtap.h
  *
- * $Id: wtap.h 27463 2009-02-16 07:24:04Z sfisher $
+ * $Id: wtap.h 28463 2009-05-24 22:49:36Z stig $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -208,6 +208,7 @@ extern "C" {
 #define WTAP_ENCAP_USB_LINUX_MMAPPED            115
 #define WTAP_ENCAP_GSM_UM                       116
 #define WTAP_ENCAP_DPNSS                        117
+#define WTAP_ENCAP_PACKETLOGGER                 118
 
 #define WTAP_NUM_ENCAP_TYPES                    wtap_get_num_encap_types()
 
@@ -270,6 +271,7 @@ extern "C" {
 #define WTAP_FILE_TNEF                          53
 #define WTAP_FILE_DCT3TRACE                     54
 #define WTAP_FILE_PACKETLOGGER                  55
+#define WTAP_FILE_DAINTREE_SNA                  56
 
 #define WTAP_NUM_FILE_TYPES                     wtap_get_num_file_types()
 
@@ -637,6 +639,9 @@ struct linux_usb_phdr {
     guint32 data_len;       /* amount of urb data really present in this event */
 };
 
+#define LIBPCAP_BT_PHDR_SENT    0
+#define LIBPCAP_BT_PHDR_RECV    1
+
 /*
  * Header prepended by libpcap to each bluetooth hci h:4 frame.
  * Values in network byte order
